package RPM::Source::Transformation::RPMEditorProvider;

use strict;
use warnings;

use Cwd;
use File::Basename;
use RPM::Source::Editor;
use RPM::Source::TransformContainer;
use RPM::Source::Transformation::Component;

our @ISA=qw/RPM::Source::Transformation::Component/;

push @RPM::Source::TransformContainer::SUPPORT_CLASSES, __PACKAGE__;
$RPM::Source::TransformContainer::RPMEditorProvider=__PACKAGE__;

#RPM::Source::TransformContainer->debug_container;

our $verbose=1;

# TODO: make them $opt{}'ed and documented in help
our ($opt_sourcedir);
our ($opt_tmpdir,$opt_safe_mode);
#### used, like in srpmconvert-fc or jppconvert
our $cleanup=1;

our @LONGOPT=(
    'cleanup!'	=> \$cleanup,
    'safe-mode'	=> \$opt_safe_mode,
    'tmpdir=s'	=> \$opt_tmpdir,
);

sub longopt_usage {
    print "
Processing options:
  SRPM unpacking options:
	--safe-mode restrain of doing unsafe operations such as spawning rpm
	--tmpdir /path/ - alternative tmpdir if default tmpdir is not big enough.
	--no-cleanup (do not remove tmp files; useful for debugging)
";
}

sub register_messages {
    my ($self,$extopt)=@_;
    ### TODO: use some fixed keys hash here
    RPM::Source::Transformation::Component::add_opt($extopt, {
	-cleanup => $cleanup,
	-safe_mode => $opt_safe_mode,
    });
}

sub rpmeditoropts2spec {
    my ($self,$inref,$opt_override)=@_;
    my $spec;
    return $spec unless $inref;
    $opt_override||=[];
    my $opts={
	VERBOSE=> $verbose,
	CLEANUP=> $cleanup,
	-tmpdir => $opt_tmpdir,
	-use_rpmbuild_be => $opt_safe_mode ? 0: 1,
	-use_shell_eval => $opt_safe_mode ? 0: 1,
	@$opt_override,
	};

    my @tmpdir_opts;
    if (not $opts->{'CLEANUP'} and $inref->[0] eq 'SOURCERPM') {
    # all those tmp_dirname hacks are just to have the RPM::Source::Editor's guts at hand on crash.
	my $tmp_dirname=basename($inref->[1]);
	$tmp_dirname=~s!.src.rpm!!;
	$tmp_dirname=cwd()."/$tmp_dirname.$$";
	push @tmpdir_opts, 	TMPDIR => $tmp_dirname;
    }
    $spec=RPM::Source::Editor->new(
	%$opts,
	@tmpdir_opts,
	@$inref,
	);
    die "FATAL: RPMEditorProvider: failed to load the file ".$inref->[1].".\n" unless $spec;
    return $spec;
}

sub rpmeditoropts2parent {
    my ($self, $parentref, $opt_override)=@_;
    $opt_override||=[];
    if ($RPM::Source::TransformContainer::ParentProvider) {
	my $parent_override=$RPM::Source::TransformContainer::ParentProvider->get();
	$parentref=$parent_override if $parent_override;
    }
    my $parent;
    if ($parentref and defined $parentref->[1]) {
	my $parentfile=$parentref->[1];
	die "FATAL: RPMEditorProvider: parent file does not exist: $parentfile.\n" unless -e $parentfile;
	$parent=$self->rpmeditoropts2spec(
	    $parentref, [ CLEANUP => 0 , @$opt_override ] );
    }
    return $parent;
}



1;
